package model

import (
	"context"
	"gorm.io/gorm"
	"yx-dataset-server/app/errors"
	"yx-dataset-server/app/model/entity"
	"yx-dataset-server/app/schema"
)

// NewRobotDataset 创建RobotDataset存储实例
func NewRobotDataset(db *gorm.DB) *RobotDataset {
	return &RobotDataset{db}
}

// RobotDataset RobotDataset存储
type RobotDataset struct {
	db *gorm.DB
}

func (a *RobotDataset) getQueryOption(opts ...schema.RobotDatasetQueryOptions) schema.RobotDatasetQueryOptions {
	var opt schema.RobotDatasetQueryOptions
	if len(opts) > 0 {
		opt = opts[0]
	}
	return opt
}

// Query 查询数据
func (a *RobotDataset) Query(ctx context.Context, params schema.RobotDatasetQueryParam, opts ...schema.RobotDatasetQueryOptions) (*schema.RobotDatasetQueryResult, error) {
	db := entity.GetRobotDatasetDB(ctx, a.db)
	if v := params.RobotId; v != "" {
		db = db.Where("robot_id=?", v)
	}
	if v := params.RecordIDs; len(v) > 0 {
		db = db.Where("record_id in (?)", v)
	}
	db = db.Order("id DESC")

	opt := a.getQueryOption(opts...)
	var list entity.RobotDatasets
	pr, err := WrapPageQuery(ctx, db, opt.PageParam, &list)
	if err != nil {
		return nil, errors.ErrDBServerInternalError
	}
	qr := &schema.RobotDatasetQueryResult{
		PageResult: pr,
		Data:       list.ToSchemaRobotDatasets(),
	}

	return qr, nil
}

// Get 查询指定数据
func (a *RobotDataset) Get(ctx context.Context, recordID string, opts ...schema.RobotDatasetQueryOptions) (*schema.RobotDataset, error) {
	db := entity.GetRobotDatasetDB(ctx, a.db).Where("record_id=?", recordID)
	var item entity.RobotDataset
	ok, err := FindOne(ctx, db, &item)
	if err != nil {
		return nil, errors.ErrDBServerInternalError
	} else if !ok {
		return nil, nil
	}

	return item.ToSchemaRobotDataset(), nil
}

// Create 创建数据
func (a *RobotDataset) Create(ctx context.Context, item schema.RobotDataset) error {
	RobotDataset := entity.SchemaRobotDataset(item).ToRobotDataset()
	result := entity.GetRobotDatasetDB(ctx, a.db).Create(RobotDataset)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// Update 更新数据
func (a *RobotDataset) Update(ctx context.Context, recordID string, item schema.RobotDataset) error {
	RobotDataset := entity.SchemaRobotDataset(item).ToRobotDataset()
	result := entity.GetRobotDatasetDB(ctx, a.db).Where("record_id=?", recordID).Omit("record_id", "creator").Updates(RobotDataset)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// Delete 删除数据
func (a *RobotDataset) Delete(ctx context.Context, recordID string) error {
	result := entity.GetRobotDatasetDB(ctx, a.db).Where("record_id=?", recordID).Delete(entity.RobotDataset{})
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// UpdateStatus 更新状态
func (a *RobotDataset) UpdateStatus(ctx context.Context, recordID string, status int) error {
	result := entity.GetRobotDatasetDB(ctx, a.db).Where("record_id=?", recordID).Update("status", status)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}
